@@ -50,6 +50,7 @@ def get_releases_aggregates(json_data):
     release_award_item_ids = set()
     release_contract_item_ids = set()
     item_identifier_schemes = set()
+    unique_item_ids = set()
 
     unique_currency = set()
 
@@ -153,6 +154,8 @@ def get_releases_aggregates(json_data):
             tender_items = tender.get('items', [])
             for item in tender_items:
                 item_id = item.get('id')
+                if item_id:
+                    unique_item_ids.add(item_id)
                 if item_id and release_id:
                     release_tender_item_ids.add((ocid, release_id, item_id))
                 get_item_scheme(item)
@@ -177,6 +180,8 @@ def get_releases_aggregates(json_data):
             award_items = award.get('items', [])
             for item in award_items:
                 item_id = item.get('id')
+                if item_id:
+                    unique_item_ids.add(item_id)
                 if item_id and release_id and award_id:
                     release_award_item_ids.add((ocid, release_id, award_id, item_id))
                 get_item_scheme(item)
@@ -200,6 +205,8 @@ def get_releases_aggregates(json_data):
             contract_items = contract.get('items', [])
             for item in contract_items:
                 item_id = item.get('id')
+                if item_id:
+                    unique_item_ids.add(item_id)
                 if item_id and release_id and contract_id:
                     release_contract_item_ids.add((ocid, release_id, contract_id, item_id))
                 get_item_scheme(item)
@@ -315,6 +322,7 @@ def get_releases_aggregates(json_data):
         tender_item_count=len(release_tender_item_ids),
         award_item_count=len(release_award_item_ids),
         contract_item_count=len(release_contract_item_ids),
+        unique_item_ids_count=len(unique_item_ids),
 
         item_identifier_schemes=sorted(item_identifier_schemes, key=lambda x: str(x)),
         unique_currency=sorted(unique_currency, key=lambda x: str(x)),
@@ -406,7 +414,9 @@ def get_bad_ocds_prefixes(json_data):
             if ocid and not prefix_regex.match(ocid):
                 bad_prefixes.append((ocid, 'records/%s/ocid' % (n_rec)))
 
-            for n_rel, release in enumerate(record.get('releases', {})):
+            for n_rel, release in enumerate(record.get('releases') or {}):
+                if not isinstance(release, dict):
+                    continue
                 ocid = release.get('ocid', '')
                 if ocid and not prefix_regex.match(ocid):
                     bad_prefixes.append((ocid, 'records/%s/releases/%s/ocid' % (n_rec, n_rel)))
@@ -426,7 +436,7 @@ def add_conformance_rule_errors(context, json_data, schema_obj):
     ocds_prefixes_bad_format = get_bad_ocds_prefixes(json_data)
 
     if ocds_prefixes_bad_format:
-        ocid_schema_description = schema_obj.get_release_schema_obj()['properties']['ocid']['description']
+        ocid_schema_description = schema_obj.get_schema_obj()['properties']['ocid']['description']
         ocid_info_index = ocid_schema_description.index('For more information')
         ocid_description = ocid_schema_description[:ocid_info_index]
         ocid_info_url = ocid_schema_description[ocid_info_index:].split('[')[1].split(']')[1][1:-1]
